#!/bin/bash
#
#  Copyright (C) 2008-2014 National Institute For Space Research (INPE) - Brazil.
#
#  This file is part of the TerraLib - a Framework for building GIS enabled applications.
#
#  TerraLib is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Lesser General Public License as published by
#  the Free Software Foundation, either version 3 of the License,
#  or (at your option) any later version.
#
#  TerraLib is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
#  GNU Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public License
#  along with TerraLib. See COPYING. If not, write to
#  TerraLib Team at <terralib-team@terralib.org>.
#
#  Description: Build all TerraLib Packages for Linux Ubuntu environment.
#
#  Before start, please read the "PACKAGE-INSTRUCTIONS".
#

# Valid parameter val or abort script
function valid_operation()
{
  if [ $1 -ne 0 ]; then
    echo $2
    echo ""
    exit $1
  else
    echo "done."
  fi
}

UBUNTU_VERSION=`lsb_release -rs`

clear
echo "*****************************************************"
echo "* TerraLib Package Installer for Linux Ubuntu ${UBUNTU_VERSION} *"
echo "*****************************************************"
echo ""
sleep 1s

# Defining default value to TE_VERSION if not set
if [ -z "$TE_VERSION" ]; then
  export TE_VERSION=5.2.1
fi

# Defining value to CODEBASE and OUTPUT_PATH (where to copy the final files)
export CODEBASE=`pwd`/../..

export OUTPUT_PATH=${CODEBASE}/../3rdparty

# Installing thirdparty libraries
${CODEBASE}/install/install-3rdparty-linux-ubuntu-${UBUNTU_VERSION}-deb.sh

echo ""
echo "Packaging Boost..."
echo ""
sleep 1s

./deb-boost.sh
BOOST_VERSION=$DEBVERSION
sudo dpkg -i ${OUTPUT_PATH}/packages/terralib-boost*
valid_operation $? "Error: could not install Boost"

echo ""
echo "Packaging Gdal..."
echo ""
sleep 1s

./deb-gdal.sh
GDAL_VERSION=$DEBVERSION
sudo dpkg -i ${OUTPUT_PATH}/packages/terralib-gdal*
valid_operation $? "Error: could not install Gdal"

echo ""
echo "Packaging Qt Property Browser..."
echo ""
sleep 1s

./deb-qtpb.sh
QTPB_VERSION=$DEBVERSION
sudo dpkg -i ${OUTPUT_PATH}/packages/terralib-qtpb*
valid_operation $? "Error: could not install Qt Property Browser"

echo ""
echo "Packaging Qwt..."
echo ""
sleep 1s

./deb-qwt.sh
QWT_VERSION=$DEBVERSION
sudo dpkg -i ${OUTPUT_PATH}/packages/terralib-qwt*
valid_operation $? "Error: could not install Qwt"

echo ""
echo "Packaging Wtss-Cxx..."
echo ""
sleep 1s

./deb-wtss-cxx.sh
WTSS_VERSION=$DEBVERSION
sudo dpkg -i ${OUTPUT_PATH}/packages/terralib-wtss-cxx*
valid_operation $? "Error: could not install Wtss-Cxx"

echo ""
echo "Packaging TerraLib..."
echo ""
sleep 1s

./deb-terralib.sh
sudo dpkg -i ${OUTPUT_PATH}/packages/terralib-${TE_VERSION}*
valid_operation $? "Error: could not install TerraLib"

echo ""
echo "Packaging TerraLib Layout..."
echo ""
sleep 1s

./deb-layout.sh
LAYOUT_VERSION=$DEBVERSION
sudo dpkg -i ${OUTPUT_PATH}/packages/terralib-layout*
valid_operation $? "Error: could not install TerraLib Layout"

echo ""
echo "Writing Install files..."
echo ""
sleep 1s

. install-generator.sh

echo ""
echo "Packaging All..."
echo ""
sleep 1s

if [ -d "${OUTPUT_PATH}/packages" ]; then
	cd ${OUTPUT_PATH}
	tar -czvf terralib-${TE_VERSION}-ubuntu-${UBUNTU_VERSION}.tar.gz packages/ install.sh uninstall.sh README
fi

echo "*****************************************************"
echo "* TerraLib Package Installer for Linux Ubuntu ${UBUNTU_VERSION} *"
echo "*****************************************************"
echo ""
echo "finished successfully!"